powered by
Call this function as a Rstudio addin to ask GPT to improve spelling and grammar of selected text.
gptstudio_spelling_grammar()
This function has no return value.
# Select some text in Rstudio # Then call the function as an RStudio addin if (FALSE) { gptstudio_spelling_grammar() }
Run the code above in your browser using DataLab